VERSION = "0.1.37"
LATEST_VNS3_VERSION = "4.10.1"
LATEST_VNS3_API_SPEC = (
    "https://cohesive-networks.s3.amazonaws.com/apis/vns3/vns3-v%s.oasv3.json"
    % LATEST_VNS3_VERSION.replace(".", "-")
)
LATEST_VNS3_MS_VERSION = "2.3.5"
LATEST_VNS3_MS_API_SPEC = (
    "https://cohesive-networks.s3.amazonaws.com/apis/vns3-ms/vns3ms-v%s.oasv3.json"
    % LATEST_VNS3_MS_VERSION.replace(".", "-")
)
